import React, { useState } from "react";
import SpaceManager from "./spacemanager";
import "./spaceselect.css";

interface SpaceSelectProps {
    onLoadSpace: (spaceId: string) => boolean;
    onDeleteSpace: (spaceId: string) => void;
    onRenameSpace: (newId: string) => void;
    onDuplicateSpace: (newId: string) => void;
    onCreateSpace: (spaceId: string) => void;
    spaces: string[];
    spaceId: string;
}

function SpaceSelect({
    onLoadSpace,
    spaces,
    spaceId,
    onRenameSpace,
    onDuplicateSpace,
    onCreateSpace,
    onDeleteSpace,
}: SpaceSelectProps) {
    const [selected, setSelected] = useState(spaceId);
    const [managerVisible, setMangerVisible] = useState(false);

    const handleDeleteSpace = (spaceId: string) => {
        setMangerVisible(false);
        onDeleteSpace(spaceId);
    };

    return (
        <div id="spaceselect">
            <select
                onChange={(event) => {
                    setSelected(event.target.value);
                    onLoadSpace(event.target.value);
                }}
                value={selected}
            >
                {spaces.map((spaceName: string) => (
                    <option key={spaceName} value={spaceName}>
                        {spaceName}
                    </option>
                ))}
            </select>

            <button onClick={() => setMangerVisible(!managerVisible)}>
                {/* Should be called "Space manager", but since a space is currently an unused concept for the user, graph is easier to understand */}
                Graph manager
            </button>
            {managerVisible && (
                <SpaceManager
                    spaceId={spaceId}
                    onCreateSpace={onCreateSpace}
                    onRenameSpace={onRenameSpace}
                    onDeleteSpace={handleDeleteSpace}
                    onDuplicateSpace={onDuplicateSpace}
                />
            )}
        </div>
    );
}

export default SpaceSelect;
